@@ -24,10 +24,10 @@
 #include <pinyin.h>
 #include "eim.h"
 
-ChewingScheme FcitxLibpinyinTransZhuyinLayout(FCITX_ZHUYIN_LAYOUT layout);
-DoublePinyinScheme FcitxLibpinyinTransShuangpinScheme(FCITX_SHUANGPIN_SCHEME scheme);
-PinyinAmbiguity2 FcitxLibpinyinTransAmbiguity(FCITX_AMBIGUITY ambiguity);
-PinyinCorrection2 FcitxLibpinyinTransCorrection(FCITX_CORRECTION correction);
-int FcitxLibpinyinTransDictionary(FCITX_DICTIONARY dict);
+ChewingScheme FcitxLibPinyinTransZhuyinLayout(FCITX_ZHUYIN_LAYOUT layout);
+DoublePinyinScheme FcitxLibPinyinTransShuangpinScheme(FCITX_SHUANGPIN_SCHEME scheme);
+PinyinAmbiguity2 FcitxLibPinyinTransAmbiguity(FCITX_AMBIGUITY ambiguity);
+PinyinCorrection2 FcitxLibPinyinTransCorrection(FCITX_CORRECTION correction);
+int FcitxLibPinyinTransDictionary(FCITX_DICTIONARY dict);
 
 #endif
